// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { METADATA_ATTRIBUTE } from './attributes';
import { isNodeComponent } from './dom-utils';
import { getGeneratedAnalyticsMetadata } from './utils';
const getComponentsArray = (node = document) => {
    const elementsWithMetadata = Array.from(node.querySelectorAll(`[${METADATA_ATTRIBUTE}]`));
    return elementsWithMetadata.filter(isNodeComponent);
};
const getComponentsTreeRecursive = (node, visited) => {
    const tree = [];
    const componentNodes = getComponentsArray(node);
    componentNodes.forEach(componentNode => {
        if (visited.has(componentNode)) {
            return;
        }
        visited.add(componentNode);
        const treeItem = Object.assign({}, getGeneratedAnalyticsMetadata(componentNode).contexts[0].detail);
        const children = getComponentsTreeRecursive(componentNode, visited);
        if (children.length > 0) {
            treeItem.children = children;
        }
        tree.push(treeItem);
    });
    return tree;
};
export const getComponentsTree = (node = document) => {
    if (!node) {
        return [];
    }
    return getComponentsTreeRecursive(node, new Set());
};
